@@ -2,7 +2,7 @@ import sys
 sys.path.insert(0,'../')
 
 import crawl
-trail = crawl.Crawl('/')
+trail = crawl.Crawl()
 trail.append_paths('../')
 trail.append_extensions('.py')
-print trail.find('crawl/registry')
\ No newline at end of file
+print trail.find('crawl/index')
\ No newline at end of file
